@@ -4,5 +4,7 @@ from .helper_function import calculatePerihelionDay
 from .helper_function import calculateDistanceBetweenSolisticePerhelion
 
 from .calculate_eot import calculateDifferenceEOTMinutes
-
 from .calculate_eot import plotEOT
+
+from .error_handling import errorHandlingEOT
+from .error_handling import errorHandlingPlotEOT
